import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
var BASE_CLASS = 'sui-AtomCheckbox';
var ERROR_STATES = {
  ERROR: 'error',
  SUCCESS: 'success'
};

var getErrorStateClass = function getErrorStateClass(errorState) {
  if (errorState) return BASE_CLASS + "--" + ERROR_STATES.ERROR;
  if (errorState === false) return BASE_CLASS + "--" + ERROR_STATES.SUCCESS;
  return '';
};

var AtomCheckbox = function AtomCheckbox(_ref) {
  var id = _ref.id,
      disabled = _ref.disabled,
      checked = _ref.checked,
      onChangeFromProps = _ref.onChange,
      errorState = _ref.errorState,
      props = _objectWithoutProperties(_ref, ["id", "disabled", "checked", "onChange", "errorState"]);

  var handleChange = function handleChange(ev) {
    var _ev$target = ev.target,
        checked = _ev$target.checked,
        name = _ev$target.name;
    if (!disabled) onChangeFromProps(ev, {
      name: name,
      value: checked
    });
  };

  var className = cx(BASE_CLASS, getErrorStateClass(errorState));
  return React.createElement(React.Fragment, null, React.createElement("input", Object.assign({
    className: className,
    type: "checkbox",
    id: id,
    disabled: disabled,
    checked: checked,
    onChange: handleChange
  }, props)));
};

AtomCheckbox.displayName = 'AtomCheckbox';
AtomCheckbox.defaultProps = {
  checked: false
};
export default AtomCheckbox;